Re: svn commit: r790809 - /tomcat/trunk/webapps/docs/developers.xml

2009-07-06 Thread Rainer Jung
On 03.07.2009 08:55, ma...@apache.org wrote:
> Modified:
> tomcat/trunk/webapps/docs/developers.xml

> +  Rainer Jung (rjung): Catalina, Clustering, Connectors

Thanks Mark!

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 47478] New: DeltaSession ignores notifyListenersOnReplication when BackupManager is used.

2009-07-06 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=47478

   Summary: DeltaSession ignores notifyListenersOnReplication when
BackupManager is used.
   Product: Tomcat 6
   Version: 6.0.20
  Platform: All
OS/Version: All
Status: NEW
  Severity: normal
  Priority: P2
 Component: Cluster
AssignedTo: dev@tomcat.apache.org
ReportedBy: fujino.keii...@oss.ntt.co.jp


When BackupManager is used,
DeltaSession notifies session listener even if notifyListenersOnReplication is
set to false. 

The cause is in the following o.a.c.h.s.DeltaSession#applyDiff's codes. 

public void applyDiff(byte[] diff, int offset, int length) throws IOException,
ClassNotFoundException {
try {
...
getDeltaRequest().execute(this);
} finally {
Thread.currentThread().setContextClassLoader(contextLoader);
}
}finally {
unlock();
}
}

DeltaSession always notifies the session listener regardless of the value of
notifyListenersOnReplication. 
Do not notify the session listener when notifyListenersOnReplication is set to
false. 

I think that I should add notifyListenersOnReplication to the second parameter 
when o.a.c.h.s.DeltaRequest#execute is invoked. 
For instance, as follows.

[start.]

Index: java/org/apache/catalina/ha/session/DeltaSession.java
===
--- java/org/apache/catalina/ha/session/DeltaSession.java(revision 763870 ( 
https://svn.apache.org/viewcvs.cgi?view=rev&rev=763870 ))
+++ java/org/apache/catalina/ha/session/DeltaSession.java(working copy)
@@ -175,7 +175,7 @@
 ClassLoader[] loaders = getClassLoaders();
 if (loaders != null && loaders.length > 0)

Thread.currentThread().setContextClassLoader(loaders[0]);
-getDeltaRequest().execute(this);
+getDeltaRequest().execute(this, ((ClusterManager)
getManager()).isNotifyListenersOnReplication());
 } finally {

Thread.currentThread().setContextClassLoader(contextLoader);
 }

[end.]

Best regards

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Tomcat Wiki] Update of "SummerOfCode2009" by xxd82329

2009-07-06 Thread Apache Wiki
Dear Wiki user,

You have subscribed to a wiki page or wiki category on "Tomcat Wiki" for change 
notification.

The following page has been changed by xxd82329:
http://wiki.apache.org/tomcat/SummerOfCode2009

--
  
  5. Valve interface has a event() method which is used to process a comet 
event. Filters need not to worry about whether it is a comet event or not. So 
how can we reflect this part in our new filter-based structure? 
  
+ 6. Do we really need to move the logic in 
StandardEngine/StandardHost/StandardContextValve into some filters? Since the 
logic of these classes is purely servlet-engine concerned, I do not think those 
logic could be reused by filters. Any comments? 
+ 
+ 7. My solution now to load configuration in $CATALINA_BASE/conf/server.xml is 
to add a CallMapParamRule.class to collect the attribute-value pairs into a 
map, and this map is the initiation parameter of a filter. A method with 
signature -- "addFilterWithConfig(Class filterClass, 
Map paramMap)" will be added in StandardEngine/Host/Context to 
add new filters into it. The main content of CallMapParamRule is as blow: 
+ 
+ public void begin(String namespace, String name, Attributes attributes)
+ throws Exception {
+ for (int i = 0, count = attributes.getLength(); i < count; i++) {
+ // here we do not deal with the className attribute, since it
+ // is used as the class name that will be initiated.
+ if("className".equalsIgnoreCase(attributes.getLocalName(i))) {
+ continue;
+ }
+ paramMap.put(attributes.getLocalName(i), attributes.getValue(i));
+ }
+ digester.getLogger().debug(paramMap);
+ Object parameters[] = (Object[]) digester.peekParams();
+ parameters[paramIndex] = paramMap;
+ }
+ 
+ In order to add those newly added filters into the FilterChain, the 
ApplicationFilterFactory class also need to be altered. 
+ 
+ Any comments about this solution? Or are there a better one?
+ 

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r791524 - /tomcat/trunk/java/org/apache/catalina/ha/session/DeltaSession.java

2009-07-06 Thread fhanik
Author: fhanik
Date: Mon Jul  6 15:45:32 2009
New Revision: 791524

URL: http://svn.apache.org/viewvc?rev=791524&view=rev
Log:
Fix 
https://issues.apache.org/bugzilla/show_bug.cgi?id=47478
Patch provided by Keiichi Fujino


Modified:
tomcat/trunk/java/org/apache/catalina/ha/session/DeltaSession.java

Modified: tomcat/trunk/java/org/apache/catalina/ha/session/DeltaSession.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/ha/session/DeltaSession.java?rev=791524&r1=791523&r2=791524&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/ha/session/DeltaSession.java 
(original)
+++ tomcat/trunk/java/org/apache/catalina/ha/session/DeltaSession.java Mon Jul  
6 15:45:32 2009
@@ -175,7 +175,7 @@
 ClassLoader[] loaders = getClassLoaders();
 if (loaders != null && loaders.length > 0)
 
Thread.currentThread().setContextClassLoader(loaders[0]);
-getDeltaRequest().execute(this);
+getDeltaRequest().execute(this, 
((ClusterManager)getManager()).isNotifyListenersOnReplication());
 } finally {
 
Thread.currentThread().setContextClassLoader(contextLoader);
 }



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 47478] DeltaSession ignores notifyListenersOnReplication when BackupManager is used.

2009-07-06 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=47478


Filip Hanik  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||FIXED




--- Comment #1 from Filip Hanik   2009-07-06 08:45:59 PST ---
Fixed in revision 791524 ( 
https://svn.apache.org/viewcvs.cgi?view=rev&rev=791524 ).
Suggested for inclusion in Tomcat 6.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r791526 - /tomcat/tc6.0.x/trunk/STATUS.txt

2009-07-06 Thread fhanik
Author: fhanik
Date: Mon Jul  6 15:49:29 2009
New Revision: 791526

URL: http://svn.apache.org/viewvc?rev=791526&view=rev
Log:
proposal

Modified:
tomcat/tc6.0.x/trunk/STATUS.txt

Modified: tomcat/tc6.0.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/STATUS.txt?rev=791526&r1=791525&r2=791526&view=diff
==
--- tomcat/tc6.0.x/trunk/STATUS.txt (original)
+++ tomcat/tc6.0.x/trunk/STATUS.txt Mon Jul  6 15:49:29 2009
@@ -183,3 +183,9 @@
   http://svn.apache.org/viewvc?rev=791331&view=rev (align platforms / bug 
39194)
   +1: markt
   -1: 
+  
+* Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=47478
+  https://svn.apache.org/viewcvs.cgi?view=rev&rev=791524
+  +1: fhanik
+  -1: 
+  
\ No newline at end of file



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Session replication without Apache

2009-07-06 Thread Manu_SF

Hi,

I have a working "prototype" tomcat cluster with 2 worker nodes connected to
Apache webserver as the Loadbalancer with mod_jk connectors. The session
replication works like a charm with these 2 nodes.

However, my ultimate goal is to deploy it over a system that does NOT have
Apache (Instead has a Big-ip hardware loadbalancer). 

My question is - Is there a way to implement session replication on tomcat
nodes without Apache?

Thanks,
Manu
--- tomcat/trunk/webapps/docs/config/filter.xml (original)
+++ tomcat/trunk/webapps/docs/config/filter.xml Mon Jul  6 21:19:39 2009
@@ -111,8 +111,6 @@
 
   
 
-  
-
 
 
 



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 46085] Session are incorrectly expired due to thread unsafe code

2009-07-06 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=46085


Daniel  changed:

   What|Removed |Added

 CC||daniel.beier.b...@gmail.com




--- Comment #3 from Daniel   2009-07-06 15:04:28 
PST ---
(In reply to comment #2)
> This has been fixed in 6.0.x and will be included 6.0.19 onwards.

We encountered random session timeouts with Tomcat 6.0.16 and IBM JVM 1.5.  I
tested Tomcat 6.0.20 and still got random session timeouts.  I downloaded the
Tomcat source code, declared StandardSession.isValid and StandardSession.access
 synchronized, rebuild and used the updated catalina.jar in my Tomcat
installation.  I ran a lot of tests and so far haven't seen random session
timeouts.  Should this bug be reopened?

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 46085] Session are incorrectly expired due to thread unsafe code

2009-07-06 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=46085





--- Comment #4 from Mark Thomas   2009-07-06 15:15:42 PST ---
Looking at the code, I can't see why syncs shouldn't be necessary. Does this
still happen with a Sun JVM?

Additionally, if you are worried about correct session expiration you should
use ACTIVITY_CHECK or STRICT_SERVLET_COMPLIANCE (see
http://tomcat.apache.org/tomcat-6.0-doc/config/systemprops.html)

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r791634 - /tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java

2009-07-06 Thread markt
Author: markt
Date: Mon Jul  6 22:20:11 2009
New Revision: 791634

URL: http://svn.apache.org/viewvc?rev=791634&view=rev
Log:
Make webDAV fix filter more sophisticated. Eventual aim is to provide fixes 
tailored to whichever broken client is trying to connect. Once I figure out how 
the client is broken of course. In the meantime, log when we know things go 
wrong. First up XP x64 SP2.

Modified:
tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java

Modified: tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java?rev=791634&r1=791633&r2=791634&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java 
(original)
+++ tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java Mon Jul  
6 22:20:11 2009
@@ -40,15 +40,37 @@
  * 
  * Generally each different version of the MS client has a different set of
  * problems.
+ * 
  * TODO: Update this filter to recognise specific MS clients and apply the
  *   appropriate workarounds for that particular client
- *   
+ *   
  * As a filter, this is configured in web.xml like any other Filter. You 
usually
  * want to map this filter to whatever your WebDAV servlet is mapped to.
+ * 
+ * In addition to the issues fixed by this Filter, the following issues have
+ * also been observed that cannot be fixed by this filter. Where possible the
+ * filter will add an message to the logs.
+ * 
+ * XP x64 SP2 (MiniRedir Version 3790
+ * 
+ *   Only connects to port 80
+ *   Requires an upper case context path
+ *   Unknown issue means it doesn't work
+ * 
  */
 
 public class WebdavFixFilter implements Filter {
 
+private static final String LOG_MESSAGE_PREAMBLE =
+"WebdavFixFilter: Detected client problem: ";
+
+/* Start string for all versions */
+private static final String UA_MINIDIR_START =
+"Microsoft-WebDAV-MiniRedir";
+/* XP 64-bit SP2 */
+private static final String UA_MINIDIR_3790 =
+"Microsoft-WebDAV-MiniRedir/5.2.3790";
+
 @Override
 public void init(FilterConfig filterConfig) throws ServletException {
 }
@@ -72,10 +94,30 @@
HttpServletRequest httpRequest = ((HttpServletRequest) request);
HttpServletResponse httpResponse = ((HttpServletResponse) 
response);
String ua = httpRequest.getHeader("User-Agent");
-   if (ua != null && ua.contains("MiniRedir")) {
-   httpResponse.sendRedirect(buildRedirect(httpRequest));
+   
+   if (ua == null || ua.length() == 0 ||
+   !ua.startsWith(UA_MINIDIR_START)) {
+   // No UA or starts with non MS value
+   // Hope everything just works...
+   chain.doFilter(request, response);
+   } else if (ua.startsWith(UA_MINIDIR_3790)) {
+   // XP 64-bit SP2
+   // Check context path case
+   if (!httpRequest.getContextPath().equals(
+   httpRequest.getContextPath().toUpperCase())) {
+   log(request,
+   "XP-x64-SP2 expects context path to be upper 
case");
+   }
+   // Some other, as yet unknown issue means I can't get this 
client
+   // to work 
+   log(request, "XP-x64-SP2 is known not to work with WebDAV 
Servlet");
+   
+   chain.doFilter(request, response);
} else {
-   chain.doFilter(request, response);
+   // Don't know which MS client it is - try the redirect with 
an
+   // explicit port in the hope that it moves the client to a 
different
+   // WebDAV implementation that works
+   httpResponse.sendRedirect(buildRedirect(httpRequest));
}   
}
 
@@ -94,4 +136,9 @@
 return location.toString();
 }
 
+private void log(ServletRequest request, String msg) {
+StringBuilder builder = new StringBuilder(LOG_MESSAGE_PREAMBLE);
+builder.append(msg);
+request.getServletContext().log(builder.toString());
+}
 }



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r791640 - /tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java

2009-07-06 Thread markt
Author: markt
Date: Mon Jul  6 22:41:38 2009
New Revision: 791640

URL: http://svn.apache.org/viewvc?rev=791640&view=rev
Log:
XP 32-bit SP3 works with the re-direct

Modified:
tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java

Modified: tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java?rev=791640&r1=791639&r2=791640&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java 
(original)
+++ tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java Mon Jul  
6 22:41:38 2009
@@ -67,8 +67,12 @@
 /* Start string for all versions */
 private static final String UA_MINIDIR_START =
 "Microsoft-WebDAV-MiniRedir";
+/* XP 32-bit SP3 */
+private static final String UA_MINIDIR_5_1_2600 =
+"Microsoft-WebDAV-MiniRedir/5.1.2600";
+
 /* XP 64-bit SP2 */
-private static final String UA_MINIDIR_3790 =
+private static final String UA_MINIDIR_5_2_3790 =
 "Microsoft-WebDAV-MiniRedir/5.2.3790";
 
 @Override
@@ -100,7 +104,10 @@
// No UA or starts with non MS value
// Hope everything just works...
chain.doFilter(request, response);
-   } else if (ua.startsWith(UA_MINIDIR_3790)) {
+   } else if (ua.startsWith(UA_MINIDIR_5_1_2600)) {
+   // XP 32-bit SP3 - needs redirect with explicit port
+   httpResponse.sendRedirect(buildRedirect(httpRequest));
+   } else if (ua.startsWith(UA_MINIDIR_5_2_3790)) {
// XP 64-bit SP2
// Check context path case
if (!httpRequest.getContextPath().equals(



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r791641 - /tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java

2009-07-06 Thread markt
Author: markt
Date: Mon Jul  6 22:42:10 2009
New Revision: 791641

URL: http://svn.apache.org/viewvc?rev=791641&view=rev
Log:
Typo

Modified:
tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java

Modified: tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java?rev=791641&r1=791640&r2=791641&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java 
(original)
+++ tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java Mon Jul  
6 22:42:10 2009
@@ -51,7 +51,7 @@
  * also been observed that cannot be fixed by this filter. Where possible the
  * filter will add an message to the logs.
  * 
- * XP x64 SP2 (MiniRedir Version 3790
+ * XP x64 SP2 (MiniRedir Version 3790)
  * 
  *   Only connects to port 80
  *   Requires an upper case context path



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r791643 - /tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java

2009-07-06 Thread markt
Author: markt
Date: Mon Jul  6 22:52:31 2009
New Revision: 791643

URL: http://svn.apache.org/viewvc?rev=791643&view=rev
Log:
Upper case was a red herring.
Thanks to http://greenbytes.de/tech/webdav/webdav-redirector-list.html

Modified:
tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java

Modified: tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java?rev=791643&r1=791642&r2=791643&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java 
(original)
+++ tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java Mon Jul  
6 22:52:31 2009
@@ -54,7 +54,6 @@
  * XP x64 SP2 (MiniRedir Version 3790)
  * 
  *   Only connects to port 80
- *   Requires an upper case context path
  *   Unknown issue means it doesn't work
  * 
  */
@@ -109,14 +108,12 @@
httpResponse.sendRedirect(buildRedirect(httpRequest));
} else if (ua.startsWith(UA_MINIDIR_5_2_3790)) {
// XP 64-bit SP2
-   // Check context path case
-   if (!httpRequest.getContextPath().equals(
-   httpRequest.getContextPath().toUpperCase())) {
+   if (!"".equals(httpRequest.getContextPath())) {
log(request,
-   "XP-x64-SP2 expects context path to be upper 
case");
+   "XP-x64-SP2 clients only work with the root 
context");
}
-   // Some other, as yet unknown issue means I can't get this 
client
-   // to work 
+   // Namespace issue maybe
+   // see 
http://greenbytes.de/tech/webdav/webdav-redirector-list.html
log(request, "XP-x64-SP2 is known not to work with WebDAV 
Servlet");

chain.doFilter(request, response);



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[PROPOSAL] Remove SVN keywords from JavaDoc

2009-07-06 Thread Konstantin Kolinko
As was written early in this my thread:
http://www.nabble.com/Coding-Guidelines%2C-encodings%2C-keywords-td23662661.html
(http://markmail.org/thread/d6dsgrsfvnuzclt7)

there are problems with Subversion $Date$ keyword:
1. It uses localized names for the month and the day of the week
2. It writes those localized strings using UTF-8, while our sources
are ISO-8859-1
3. The time that is printed is in local timezone

There are two possible solutions (besides ignoring the issue):
a) Use $Id:$ keyword instead
b) Remove the keyword

For the java sources, I propose the simpler one of the above:

I propose to remove *all* SVN keywords from our *.java sources, where they are
used in JavaDoc comments.
That includes the following four keywords: Author Date Id Revision

As it is a documentation change, I won't propose a patch, but go C-T-R.

What are your opinions?
If there are any objections to such a change, please write so.


I think that having SVN keywords in JavaDoc is not so useful, because
- Classes do change often, but their JavaDoc do not so.
- You know, to what TC release your JavaDoc corresponds to. Why to need more?

Best regards,
Konstantin Kolinko

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [PROPOSAL] Remove SVN keywords from JavaDoc

2009-07-06 Thread Rainer Jung
On 07.07.2009 02:01, Konstantin Kolinko wrote:
> As was written early in this my thread:
> http://www.nabble.com/Coding-Guidelines%2C-encodings%2C-keywords-td23662661.html
> (http://markmail.org/thread/d6dsgrsfvnuzclt7)
> 
> there are problems with Subversion $Date$ keyword:
> 1. It uses localized names for the month and the day of the week
> 2. It writes those localized strings using UTF-8, while our sources
> are ISO-8859-1
> 3. The time that is printed is in local timezone
> 
> There are two possible solutions (besides ignoring the issue):
> a) Use $Id:$ keyword instead
> b) Remove the keyword
> 
> For the java sources, I propose the simpler one of the above:
> 
> I propose to remove *all* SVN keywords from our *.java sources, where they are
> used in JavaDoc comments.
> That includes the following four keywords: Author Date Id Revision
> 
> As it is a documentation change, I won't propose a patch, but go C-T-R.
> 
> What are your opinions?
> If there are any objections to such a change, please write so.
> 
> 
> I think that having SVN keywords in JavaDoc is not so useful, because
> - Classes do change often, but their JavaDoc do not so.
> - You know, to what TC release your JavaDoc corresponds to. Why to need more?

I had a look at the java folder in trunk. The following files contain
SVN keywords outside of javadoc but inside comments (it seems they only
use $Id):

Java-Files:

javax/servlet/AsyncContext.java
javax/servlet/AsyncEvent.java
javax/servlet/AsyncListener.java
javax/servlet/DispatcherType.java
javax/servlet/FilterRegistration.java
javax/servlet/Registration.java
javax/servlet/ServletContainerInitializer.java
javax/servlet/ServletRegistration.java
javax/servlet/SessionCookieConfig.java
javax/servlet/SessionTrackingMode.java
javax/servlet/annotation/HandlesTypes.java
javax/servlet/annotation/MultipartConfig.java
javax/servlet/annotation/WebFilter.java
javax/servlet/annotation/WebInitParam.java
javax/servlet/annotation/WebListener.java
javax/servlet/annotation/WebServlet.java
org/apache/catalina/startup/ConnectorCreateRule.java
org/apache/catalina/startup/SetNextNamingRule.java
org/apache/tomcat/util/digester/AbstractObjectCreationFactory.java
org/apache/tomcat/util/digester/AbstractRulesImpl.java
org/apache/tomcat/util/digester/ArrayStack.java
org/apache/tomcat/util/digester/CallMethodRule.java
org/apache/tomcat/util/digester/CallParamRule.java
org/apache/tomcat/util/digester/Digester.java
org/apache/tomcat/util/digester/FactoryCreateRule.java
org/apache/tomcat/util/digester/GenericParser.java
org/apache/tomcat/util/digester/NodeCreateRule.java
org/apache/tomcat/util/digester/ObjectCreateRule.java
org/apache/tomcat/util/digester/ObjectCreationFactory.java
org/apache/tomcat/util/digester/ObjectParamRule.java
org/apache/tomcat/util/digester/ParserFeatureSetterFactory.java
org/apache/tomcat/util/digester/PathCallParamRule.java
org/apache/tomcat/util/digester/Rule.java
org/apache/tomcat/util/digester/RuleSet.java
org/apache/tomcat/util/digester/RuleSetBase.java
org/apache/tomcat/util/digester/Rules.java
org/apache/tomcat/util/digester/RulesBase.java
org/apache/tomcat/util/digester/SetNextRule.java
org/apache/tomcat/util/digester/SetPropertiesRule.java
org/apache/tomcat/util/digester/SetPropertyRule.java
org/apache/tomcat/util/digester/SetRootRule.java
org/apache/tomcat/util/digester/SetTopRule.java
org/apache/tomcat/util/digester/WithDefaultsRulesWrapper.java
org/apache/tomcat/util/digester/XercesParser.java
org/apache/tomcat/util/net/SSLSessionManager.java

LocalStrings.properties:

javax/servlet/http/LocalStrings_es.properties
org/apache/catalina/realm/LocalStrings.properties
org/apache/catalina/realm/LocalStrings_es.properties
org/apache/catalina/realm/LocalStrings_fr.properties
org/apache/catalina/realm/LocalStrings_ja.properties
org/apache/coyote/ajp/LocalStrings.properties
org/apache/coyote/http11/LocalStrings.properties
org/apache/coyote/http11/LocalStrings_es.properties
org/apache/coyote/http11/LocalStrings_fr.properties
org/apache/coyote/http11/LocalStrings_ja.properties
org/apache/jasper/resources/LocalStrings.properties
org/apache/jasper/resources/LocalStrings_es.properties
org/apache/jasper/resources/LocalStrings_fr.properties
org/apache/jasper/resources/LocalStrings_ja.properties
org/apache/naming/LocalStrings_es.properties

Others

javax/servlet/resources/XMLSchema.dtd
javax/servlet/resources/datatypes.dtd
org/apache/tomcat/util/modeler/mbeans-descriptors.dtd
org/apache/tomcat/util/http/fileupload/package.html

I fully agree in getting rid of Date, Revision and Author.

I'm not so sure about using Id. Somehow I like the idea of being able to
identify a file version even if someone isolated from the context it has
been delivered in. I am talking about source files themselves, not about
generated javadoc.

As long as the file is part of an archive file or contained in an
extracted archive file directory structure, the version of the archive
corresponds to a tag and that is enough to k

svn commit: r791666 - /tomcat/tc6.0.x/trunk/STATUS.txt

2009-07-06 Thread rjung
Author: rjung
Date: Tue Jul  7 01:15:25 2009
New Revision: 791666

URL: http://svn.apache.org/viewvc?rev=791666&view=rev
Log:
Vote.

Modified:
tomcat/tc6.0.x/trunk/STATUS.txt

Modified: tomcat/tc6.0.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/STATUS.txt?rev=791666&r1=791665&r2=791666&view=diff
==
--- tomcat/tc6.0.x/trunk/STATUS.txt (original)
+++ tomcat/tc6.0.x/trunk/STATUS.txt Tue Jul  7 01:15:25 2009
@@ -137,30 +137,30 @@
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=37984
   Strip {MD5} as well as {SHA} from digested passwords
   http://svn.apache.org/viewvc?rev=790405&view=rev
-  +1: markt, kkolinko
+  +1: markt, kkolinko, rjung
   -1: 
 
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=47149
   Explicitly specify encoding for the source files
   http://people.apache.org/~kkolinko/patches/2009-07-04_tc6_encodings.patch
-  +1: kkolinko, markt
+  +1: kkolinko, markt, rjung
   -1:
 
 * Add *.rtf to the list of exclusions in fixcrlf task.
   http://svn.apache.org/viewvc?rev=791184&view=rev
-  +1: kkolinko, markt
+  +1: kkolinko, markt, rjung
   -1:
 
 * Remove build-webapps-precompile target from dist.xml
   Discussion: http://markmail.org/thread/ymgbgqm3lav6rnjh
   Patch:
   
http://people.apache.org/~kkolinko/patches/2009-07-04_tc6_remove-webapps-precompile.patch
-  +1: kkolinko, markt
+  +1: kkolinko, markt, rjung
   -1:
 
 * Specify explicit encoding when performing replace task
   http://svn.apache.org/viewvc?rev=791194&view=rev
-  +1: kkolinko, markt
+  +1: kkolinko, markt, rjung
   -1:
 
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=38797
@@ -174,18 +174,18 @@
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=38897
   Add uri of broken TLD to error message to help debugging
   http://svn.apache.org/viewvc?rev=791243&view=rev
-  +1: markt, kkolinko
+  +1: markt, kkolinko, rjung
   -1: 
 
 * Various script improvements (free free to vote for them individually)
   http://svn.apache.org/viewvc?rev=791326&view=rev (remove JSSE)
   http://svn.apache.org/viewvc?rev=791328&view=rev (display classpath)
   http://svn.apache.org/viewvc?rev=791331&view=rev (align platforms / bug 
39194)
-  +1: markt
+  +1: markt, rjung (all 3 patches)
   -1: 
-  
+
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=47478
   https://svn.apache.org/viewcvs.cgi?view=rev&rev=791524
-  +1: fhanik
+  +1: fhanik, rjung
   -1: 
-  
\ No newline at end of file
+  



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r791670 - /tomcat/current/tc5.5.x/STATUS.txt

2009-07-06 Thread rjung
Author: rjung
Date: Tue Jul  7 01:41:55 2009
New Revision: 791670

URL: http://svn.apache.org/viewvc?rev=791670&view=rev
Log:
Vote.

Modified:
tomcat/current/tc5.5.x/STATUS.txt

Modified: tomcat/current/tc5.5.x/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/current/tc5.5.x/STATUS.txt?rev=791670&r1=791669&r2=791670&view=diff
==
--- tomcat/current/tc5.5.x/STATUS.txt (original)
+++ tomcat/current/tc5.5.x/STATUS.txt Tue Jul  7 01:41:55 2009
@@ -55,7 +55,7 @@
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=37984
   Strip {MD5} as well as {SHA} from digested passwords
   http://svn.apache.org/viewvc?rev=790405&view=rev
-  +1: markt, kkolinko
+  +1: markt, kkolinko, rjung
   -1: 
 
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=38743
@@ -68,7 +68,7 @@
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=47149
   Explicitly specify encoding for the source files
   http://people.apache.org/~kkolinko/patches/2009-07-04_tc55_encodings.patch
-  +1: kkolinko, markt
+  +1: kkolinko, markt, rjung
   -1:
 
 * Document minimum required Ant version to be 1.6.2, instead of 1.5.x
@@ -77,7 +77,7 @@
   (Though it is a docs patch, I think it is an important change)
   Patch for BUILDING.txt:
   http://people.apache.org/~kkolinko/patches/2009-07-04_tc55_antversion.patch
-  +1: kkolinko
+  +1: kkolinko, rjung
   +1: markt - min JRE version is 1.4, even with the compat package
   -1:
 
@@ -88,12 +88,12 @@
  (We have a License.rtf file)
   Note, that fixlast option for fixcrlf task is since Ant 1.6.1 only.
   http://people.apache.org/~kkolinko/patches/2009-07-04_tc55_fixcrlf.patch
-  +1: kkolinko, markt
+  +1: kkolinko, markt, rjung
   -1:
 
 * Specify explicit encoding when performing filtering in copy and replace tasks
   
http://people.apache.org/~kkolinko/patches/2009-07-04_tc55_copy-encodings.patch
-  +1: kkolinko, markt
+  +1: kkolinko, markt, rjung
   -1:
 
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=47464
@@ -101,8 +101,9 @@
   Also, I limited the scope of fixcrlf task in package-src-tgz target
   to process the sources dir only.
   http://people.apache.org/~kkolinko/patches/2009-07-05_tc55_packsources.patch
-  +1: kkolinko, markt
+  +1: kkolinko, markt, rjung
   -1:
+  rjung: Not sure, why you exclude bin instead of *.class
 
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=38797
   Reverts previous fix for
@@ -116,12 +117,12 @@
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=38897
   Add uri of broken TLD to error message to help debugging
   http://svn.apache.org/viewvc?rev=791243&view=rev
-  +1: markt, kkolinko
+  +1: markt, kkolinko, rjung
   -1: 
 
 * Various script improvements (free free to vote for them individually)
   http://svn.apache.org/viewvc?rev=791326&view=rev (remove JSSE)
   http://svn.apache.org/viewvc?rev=791328&view=rev (display classpath)
   http://svn.apache.org/viewvc?rev=791331&view=rev (align platforms / bug 
39194)
-  +1: markt
+  +1: markt, rjung (all three patches)
   -1: 



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r791671 - in /tomcat/tc6.0.x/trunk: ./ java/org/apache/catalina/ha/tcp/ java/org/apache/catalina/tribes/transport/

2009-07-06 Thread rjung
Author: rjung
Date: Tue Jul  7 01:47:49 2009
New Revision: 791671

URL: http://svn.apache.org/viewvc?rev=791671&view=rev
Log:
Remove some obsolete (and partially broken) message strings.

Backport of r789944 from trunk.

Modified:
tomcat/tc6.0.x/trunk/STATUS.txt
tomcat/tc6.0.x/trunk/java/org/apache/catalina/ha/tcp/LocalStrings.properties

tomcat/tc6.0.x/trunk/java/org/apache/catalina/ha/tcp/LocalStrings_es.properties

tomcat/tc6.0.x/trunk/java/org/apache/catalina/tribes/transport/LocalStrings.properties

tomcat/tc6.0.x/trunk/java/org/apache/catalina/tribes/transport/LocalStrings_es.properties

Modified: tomcat/tc6.0.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/STATUS.txt?rev=791671&r1=791670&r2=791671&view=diff
==
--- tomcat/tc6.0.x/trunk/STATUS.txt (original)
+++ tomcat/tc6.0.x/trunk/STATUS.txt Tue Jul  7 01:47:49 2009
@@ -129,11 +129,6 @@
   +1: markt
   -1: 
 
-* Remove some obsolete (and partially broken) message strings.
-  http://svn.apache.org/viewvc?rev=789944&view=rev
-  +1: rjung, kkolinko, markt
-  -1: 
-
 * Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=37984
   Strip {MD5} as well as {SHA} from digested passwords
   http://svn.apache.org/viewvc?rev=790405&view=rev

Modified: 
tomcat/tc6.0.x/trunk/java/org/apache/catalina/ha/tcp/LocalStrings.properties
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/catalina/ha/tcp/LocalStrings.properties?rev=791671&r1=791670&r2=791671&view=diff
==
--- 
tomcat/tc6.0.x/trunk/java/org/apache/catalina/ha/tcp/LocalStrings.properties 
(original)
+++ 
tomcat/tc6.0.x/trunk/java/org/apache/catalina/ha/tcp/LocalStrings.properties 
Tue Jul  7 01:47:49 2009
@@ -77,11 +77,3 @@
 SimpleTcpCluster.log.receive=RECEIVE {0,date}:{0,time} {1,number} 
{2}:{3,number,integer} {4} {5}
 SimpleTcpCluster.log.send=SEND {0,date}:{0,time} {1,number} 
{2}:{3,number,integer} {4} 
 SimpleTcpCluster.log.send.all=SEND {0,date}:{0,time} {1,number} - {2}
-SocketReplictionListener.allreadyExists=ServerSocket [{0}:{1}] allready 
started!
-SocketReplictionListener.accept.failure=ServerSocket [{0}:{1}] - Exception to 
start thread or accept server socket
-SocketReplictionListener.open=Open Socket at [{0}:{1}]
-SocketReplictionListener.openclose.failure=ServerSocket [{0}:{1}] - Exception 
to open or close server socket
-SocketReplictionListener.portbusy=Port busy at [{0}:{i}] - reason [{2}]
-SocketReplictionListener.serverSocket.notExists=Fatal error: Receiver socket 
not bound address={0} port={1} maxport={2}
-SocketReplictionListener.timeout=Receiver ServerSocket no started [{0}:{1}] - 
reason: timeout={2} or listen={3}
-SocketReplictionListener.unlockSocket.failure=UnLocksocket failure at 
ServerSocket [{0:{1}]

Modified: 
tomcat/tc6.0.x/trunk/java/org/apache/catalina/ha/tcp/LocalStrings_es.properties
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/catalina/ha/tcp/LocalStrings_es.properties?rev=791671&r1=791670&r2=791671&view=diff
==
--- 
tomcat/tc6.0.x/trunk/java/org/apache/catalina/ha/tcp/LocalStrings_es.properties 
(original)
+++ 
tomcat/tc6.0.x/trunk/java/org/apache/catalina/ha/tcp/LocalStrings_es.properties 
Tue Jul  7 01:47:49 2009
@@ -77,11 +77,3 @@
 SimpleTcpCluster.log.receive = RECEIVE {0,date}\:{0,time} {1,number} 
{2}\:{3,number,integer} {4} {5}
 SimpleTcpCluster.log.send = SEND {0,date}\:{0,time} {1,number} 
{2}\:{3,number,integer} {4} 
 SimpleTcpCluster.log.send.all = SEND {0,date}\:{0,time} {1,number} - {2}
-SocketReplictionListener.allreadyExists = ServerSocket [{0}\:{1}] allready 
started\!
-SocketReplictionListener.accept.failure = ServerSocket [{0}\:{1}] - Exception 
to start thread or accept server socket
-SocketReplictionListener.open = Open Socket at [{0}\:{1}]
-SocketReplictionListener.openclose.failure = ServerSocket [{0}\:{1}] - 
Exception to open or close server socket
-SocketReplictionListener.portbusy = Port busy at [{0}\:{i}] - reason [{2}]
-SocketReplictionListener.serverSocket.notExists = Fatal error\: Receiver 
socket not bound address\={0} port\={1} maxport\={2}
-SocketReplictionListener.timeout = Receiver ServerSocket no started [{0}\:{1}] 
- reason\: timeout\={2} or listen\={3}
-SocketReplictionListener.unlockSocket.failure = UnLocksocket failure at 
ServerSocket [{0\:{1}]

Modified: 
tomcat/tc6.0.x/trunk/java/org/apache/catalina/tribes/transport/LocalStrings.properties
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/catalina/tribes/transport/LocalStrings.properties?rev=791671&r1=791670&r2=791671&view=diff
==
--- 
tomcat/tc6.0.x/trunk/java/org/apache/catalina/tribes/transport/LocalStrings.properties
 (original)
+++ 
tomcat/tc6.0.x/trunk/

Re: svn commit: r791670 - /tomcat/current/tc5.5.x/STATUS.txt

2009-07-06 Thread Konstantin Kolinko
2009/7/7  :
> Author: rjung
> Date: Tue Jul  7 01:41:55 2009
> New Revision: 791670
>
> URL: http://svn.apache.org/viewvc?rev=791670&view=rev
> Log:
> Vote.
>
> Modified:
>    tomcat/current/tc5.5.x/STATUS.txt
>
> @@ -101,8 +101,9 @@
>   Also, I limited the scope of fixcrlf task in package-src-tgz target
>   to process the sources dir only.
>   http://people.apache.org/~kkolinko/patches/2009-07-05_tc55_packsources.patch
> -  +1: kkolinko, markt
> +  +1: kkolinko, markt, rjung
>   -1:
> +  rjung: Not sure, why you exclude bin instead of *.class
The /bin folder is where Eclipse IDE puts the result of its own
compilation of the sources (those are *.class files as well as copied
*.properties and other resources). It is not used when building a
release, and is already included in svn:ignore property of the parent
directory.

In TC 6.0 and trunk those files are in /.settings/output

In TC 5.5 we have 5 projects (build, connectors, container, jasper,
servletapi), each of them has  in their ".classpath" files and thus its own bin
subdirectory.

Best regards,
Konstantin Kolinko

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [PROPOSAL] Remove SVN keywords from JavaDoc

2009-07-06 Thread William A. Rowe, Jr.
Rainer Jung wrote:
> 
> So I like the idea of using Id, but I am open to arguments for dropping it.

In httpd, we use;  in the reference
file, and the tag  which
is updated in order to determine how far out of sync translations have fallen.

So there is one argument for at least one embedded svn property.


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r791690 - /tomcat/current/tc5.5.x/STATUS.txt

2009-07-06 Thread kkolinko
Author: kkolinko
Date: Tue Jul  7 03:29:14 2009
New Revision: 791690

URL: http://svn.apache.org/viewvc?rev=791690&view=rev
Log:
vote

Modified:
tomcat/current/tc5.5.x/STATUS.txt

Modified: tomcat/current/tc5.5.x/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/current/tc5.5.x/STATUS.txt?rev=791690&r1=791689&r2=791690&view=diff
==
--- tomcat/current/tc5.5.x/STATUS.txt (original)
+++ tomcat/current/tc5.5.x/STATUS.txt Tue Jul  7 03:29:14 2009
@@ -126,3 +126,17 @@
   http://svn.apache.org/viewvc?rev=791331&view=rev (align platforms / bug 
39194)
   +1: markt, rjung (all three patches)
   -1: 
+  kkolinko:
++1 for the first and second patches (791326, 791328)
+-1 for the third patch
+I do not like the third patch:
+It introduces the "javac" optional command, that was not there before.
+(The "javac" command was not documented, and I think it was not working
+at all, because of missing "shift" command.
+It was introduced in http://svn.apache.org/viewvc?view=rev&revision=303625
+)
+How this "javac" is supposed to be used? One has to modify
+startup.[sh|bat] and shutdown.[sh|bat]?
+We switch between JDK and JRE based on env.variables (e.g. introduced
+through setenv.[sh|bat]). Why not to add tools.jar always when JDK is
+used?



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r791699 - in /tomcat/tc6.0.x/trunk: STATUS.txt build.xml dist.xml res/tomcat.nsi

2009-07-06 Thread mturk
Author: mturk
Date: Tue Jul  7 04:51:34 2009
New Revision: 791699

URL: http://svn.apache.org/viewvc?rev=791699&view=rev
Log:
Backport the new dist patch from trunk

Modified:
tomcat/tc6.0.x/trunk/STATUS.txt
tomcat/tc6.0.x/trunk/build.xml
tomcat/tc6.0.x/trunk/dist.xml
tomcat/tc6.0.x/trunk/res/tomcat.nsi

Modified: tomcat/tc6.0.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/STATUS.txt?rev=791699&r1=791698&r2=791699&view=diff
==
--- tomcat/tc6.0.x/trunk/STATUS.txt (original)
+++ tomcat/tc6.0.x/trunk/STATUS.txt Tue Jul  7 04:51:34 2009
@@ -99,14 +99,6 @@
   +1: fhanik, markt, mturk, rjung
   -1: 
 
-* Update release process to include new windows package zip files
-  with .dll and .exe matching a target CPU. Patch also syncs
-  and fixes nsi installer script.
-  Patch for 6.0.x is available at:
-  http://people.apache.org/~mturk/tomcat/tomcat6-package-winzip-2.patch
-  +1: mturk, kkolinko, rjung
-  -1:
-
 * When throwing Non-serializable exception, mark which argument was
   non-serializable to help tracing the cause when developing.
   http://svn.apache.org/viewvc?rev=713953&view=rev

Modified: tomcat/tc6.0.x/trunk/build.xml
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/build.xml?rev=791699&r1=791698&r2=791699&view=diff
==
--- tomcat/tc6.0.x/trunk/build.xml (original)
+++ tomcat/tc6.0.x/trunk/build.xml Tue Jul  7 04:51:34 2009
@@ -662,6 +662,12 @@
   
 
 
+
+  
+  
+  
+
+
 
   
   
@@ -755,4 +761,4 @@
 
   
 
-
\ No newline at end of file
+

Modified: tomcat/tc6.0.x/trunk/dist.xml
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/dist.xml?rev=791699&r1=791698&r2=791699&view=diff
==
--- tomcat/tc6.0.x/trunk/dist.xml (original)
+++ tomcat/tc6.0.x/trunk/dist.xml Tue Jul  7 04:51:34 2009
@@ -350,13 +350,19 @@
 tofile="${tomcat.dist}/bin/tomcat${version.major}w.exe" />

 
+tofile="${tomcat.dist}/bin/x64/tomcat${version.major}.exe" />

 
+tofile="${tomcat.dist}/bin/i64/tomcat${version.major}.exe" />

 
+   
+
+   
+
 
 
 
@@ -380,12 +386,11 @@
   forceOverwrite="yes" fileext=".md5" />
 
-
   
 
 
   
-  
 
 
@@ -430,6 +435,11 @@
 
 
 
+
+
+
+
+
   
 
 
@@ -439,6 +449,99 @@
   
message="${md5sum.binary-prefix}${final.name}.zip${line.separator}" 
append="true" />
   
 
+  
+  
+
+
+  
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+  
+  
+
+
+
+
+
+
+  
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+  
+  
+
+
+  
+
+
+
+
+
+
+  
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+  
+  
+
+
+  
+
+
+
+
+
+  
+
   
   
 
@@ -503,8 +606,13 @@
 
 
 
+
 
 
+
+
+
+
   
 
 

Modified: tomcat/tc6.0.x/trunk/res/tomcat.nsi
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/res/tomcat.nsi?rev=791699&r1=791698&r2=791699&view=diff
==
--- tomcat/tc6.0.x/trunk/res/tomcat.nsi (original)
+++ tomcat/tc6.0.x/trunk/res/tomcat.nsi Tue Jul  7 04:51:34 2009
@@ -171,19 +171,17 @@
   DetailPrint "Using Jvm: $2"
 
   SetOutPath $INSTDIR\bin
+  File bin\tom...@version_major@w.exe
+
   ; Get the current platform x86 / AMD64 / IA64
-  ExpandEnvStrings $0 "%PROCESSOR_ARCHITEW6432%"
-  StrCmp $0 "%PROCESSOR_ARCHITEW6432%" 0 +2
-  ExpandEnvStrings $0 "%PROCESSOR_ARCHITECTURE%"
-  StrCmp $0 "x86" 0 +3
+  Call FindCpuType
+  Pop $0
+  StrCmp $0 "x86" 0 +2
   File /oname=tom...@version_major@.exe bin\tom...@version_major@.exe
-  File /oname=tom...@version_major@w.exe bin\tom...@version_major@w.exe
-  StrCmp $0 "AMD64" 0 +3
-  File /oname=tom...@version_major@.exe 
bin\procrun\amd64\tom...@version_major@.exe
-  File /oname=tom...@version_major@w.exe bin\tom...@version_major@w.exe
-  StrCmp $0 "IA64" 0 +3
-  File /oname=tom...@version_major@.exe 
bin\procrun\ia64\tom...@version_major@.exe
-  File /oname=tom...@version_major@w.exe bin\tom...@version_major@w.exe
+  StrCmp $0 "x64" 0 +2
+  File /oname=tom...@version_major@.exe bin\x64\tom...@version_major@.exe
+  StrCmp $0 "i64" 

svn commit: r791706 - /tomcat/tc6.0.x/trunk/STATUS.txt

2009-07-06 Thread mturk
Author: mturk
Date: Tue Jul  7 05:14:28 2009
New Revision: 791706

URL: http://svn.apache.org/viewvc?rev=791706&view=rev
Log:
Update the patch so it includes the new native2ascii

Modified:
tomcat/tc6.0.x/trunk/STATUS.txt

Modified: tomcat/tc6.0.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/STATUS.txt?rev=791706&r1=791705&r2=791706&view=diff
==
--- tomcat/tc6.0.x/trunk/STATUS.txt (original)
+++ tomcat/tc6.0.x/trunk/STATUS.txt Tue Jul  7 05:14:28 2009
@@ -104,7 +104,7 @@
   http://svn.apache.org/viewvc?rev=713953&view=rev
   http://svn.apache.org/viewvc?rev=714002&view=rev
   6.0.x version of the patch:
-  http://people.apache.org/~mturk/tomcat/setAttribute.iae.patch
+  http://people.apache.org/~mturk/tomcat/setAttribute1.iae.patch
   +1: mturk
   -1: kkolinko: (
   good in general, but



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: svn commit: r788077 - /tomcat/tc6.0.x/trunk/STATUS.txt

2009-07-06 Thread Mladen Turk

kkoli...@apache.org wrote:

Author: kkolinko
 
 * When throwing Non-serializable exception, mark which argument was

@@ -163,6 +163,13 @@
   6.0.x version of the patch:
   http://people.apache.org/~mturk/tomcat/setAttribute.iae.patch
   +1: mturk
+  -1: kkolinko: (
+  good in general, but
+  1) please use native2ascii for LocalStrings_fr.properties
+  s/ e / \u00nn /


I made the patch before all that native2ascii stuff changed.
However I updated the patch.


+  2) o.a.c.session.ha.session.LocalString*.properties files also have this 
string.
+  Should it be removed from there, or updated there also?


This has nothing to do with the patch.
It's a separate issue that requires cleanup of o.a.c.session.ha which has
lots of unused entries probably due to copy/paste.
At least the standardSession.setAttribute.iae is never used inside
the o.a.c.session.ha package.

Regards
-- 
View this message in context: 
http://www.nabble.com/Session-replication-without-Apache-tp24359544p24359544.html
Sent from the Tomcat - Dev mailing list archive at Nabble.com.


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: Session replication without Apache

2009-07-06 Thread Mark Thomas
Manu_SF wrote:
> Hi,
> 
> I have a working "prototype" tomcat cluster with 2 worker nodes connected to
> Apache webserver as the Loadbalancer with mod_jk connectors. The session
> replication works like a charm with these 2 nodes.
> 
> However, my ultimate goal is to deploy it over a system that does NOT have
> Apache (Instead has a Big-ip hardware loadbalancer). 
> 
> My question is - Is there a way to implement session replication on tomcat
> nodes without Apache?

That would be a question for the users list.

Mark



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: Session replication without Apache

2009-07-06 Thread Manu_SF

Oh... Thanks, Mark.


markt-2 wrote:
> 
> Manu_SF wrote:
>> Hi,
>> 
>> I have a working "prototype" tomcat cluster with 2 worker nodes connected
>> to
>> Apache webserver as the Loadbalancer with mod_jk connectors. The session
>> replication works like a charm with these 2 nodes.
>> 
>> However, my ultimate goal is to deploy it over a system that does NOT
>> have
>> Apache (Instead has a Big-ip hardware loadbalancer). 
>> 
>> My question is - Is there a way to implement session replication on
>> tomcat
>> nodes without Apache?
> 
> That would be a question for the users list.
> 
> Mark
> 
> 
> 
> -
> To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
> For additional commands, e-mail: dev-h...@tomcat.apache.org
> 
> 
> 

-- 
View this message in context: 
http://www.nabble.com/Session-replication-without-Apache-tp24359544p24360627.html
Sent from the Tomcat - Dev mailing list archive at Nabble.com.


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 47482] New: HttpServletResponse.sendError( int, String ) does not use the message argument in the Reason-Phrase

2009-07-06 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=47482

   Summary: HttpServletResponse.sendError( int, String ) does not
use the message argument in the Reason-Phrase
   Product: Tomcat 5
   Version: 5.5.27
  Platform: All
OS/Version: All
Status: NEW
  Severity: regression
  Priority: P2
 Component: Unknown
AssignedTo: dev@tomcat.apache.org
ReportedBy: james.vela...@int.com


When javax.servlet.http.HttpServletResponse( int code, String message ) is
invoked, the message argument is omitted from the corresponding Status-Line's
Reason-Phrase as was the case in Tomcat 5.5.26 and earlier.

While not explicitly required, Section 6.1.1 of
http://www.ietf.org/rfc/rfc2616.txt strongly implies this to be the correct
behavior, as implemented in v 5.5.26.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 47482] HttpServletResponse.sendError( int, String ) does not use the message argument in the Reason-Phrase

2009-07-06 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=47482


Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||INVALID




--- Comment #1 from Mark Thomas   2009-07-06 12:34:39 PST ---
http://tomcat.apache.org/tomcat-5.5-doc/config/systemprops.html

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 47482] HttpServletResponse.sendError( int, String ) does not use the message argument in the Reason-Phrase

2009-07-06 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=47482





--- Comment #2 from James Velasco   2009-07-06 12:48:21 
PST ---
I got it, this is a security fix. Thanks for the response.

James

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r791616 - in /tomcat/trunk: java/org/apache/catalina/filters/WebdavFixFilter.java java/org/apache/catalina/valves/WebdavFixValve.java webapps/docs/config/filter.xml webapps/docs/config/val

2009-07-06 Thread markt
Author: markt
Date: Mon Jul  6 21:06:13 2009
New Revision: 791616

URL: http://svn.apache.org/viewvc?rev=791616&view=rev
Log:
Convert the WebDAV fix valve to a filter.
Based on a patch provided by Xie Xiaodong as part of GSOC 2009

Added:
tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java
  - copied, changed from r791216, 
tomcat/trunk/java/org/apache/catalina/valves/WebdavFixValve.java
Removed:
tomcat/trunk/java/org/apache/catalina/valves/WebdavFixValve.java
Modified:
tomcat/trunk/webapps/docs/config/filter.xml
tomcat/trunk/webapps/docs/config/valve.xml

Copied: tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java 
(from r791216, tomcat/trunk/java/org/apache/catalina/valves/WebdavFixValve.java)
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java?p2=tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java&p1=tomcat/trunk/java/org/apache/catalina/valves/WebdavFixValve.java&r1=791216&r2=791616&rev=791616&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/valves/WebdavFixValve.java (original)
+++ tomcat/trunk/java/org/apache/catalina/filters/WebdavFixFilter.java Mon Jul  
6 21:06:13 2009
@@ -15,58 +15,76 @@
  * limitations under the License.
  */
 
-package org.apache.catalina.valves;
+package org.apache.catalina.filters;
 
 import java.io.IOException;
 
+import javax.servlet.Filter;
+import javax.servlet.FilterChain;
+import javax.servlet.FilterConfig;
 import javax.servlet.ServletException;
-
-import org.apache.catalina.valves.ValveBase;
-import org.apache.catalina.connector.Request;
-import org.apache.catalina.connector.Response;
+import javax.servlet.ServletRequest;
+import javax.servlet.ServletResponse;
+import javax.servlet.http.HttpServletRequest;
+import javax.servlet.http.HttpServletResponse;
 
 /**
  * Valve that attempts to force MS WebDAV clients connecting on port 80 to use
  * a WebDAV client that actually works. Other workarounds that might help
  * include:
  * 
- *   Specifing the port, even if it is port 80, when trying to 
connect.
- *   Canceling the first authentication dialog box and then trying to
+ *   Specifying the port, even if it is port 80, when trying to 
connect.
+ *   Cancelling the first authentication dialog box and then trying to
  *   reconnect.
  * 
- * To use this valve add the following 
- * to your Engine, Host or Context as
- * required. Normally, this valve would be used at the Context
- * level.
- *
- * @version $Revision$, $Date$
+ * 
+ * Generally each different version of the MS client has a different set of
+ * problems.
+ * TODO: Update this filter to recognise specific MS clients and apply the
+ *   appropriate workarounds for that particular client
+ *   
+ * As a filter, this is configured in web.xml like any other Filter. You 
usually
+ * want to map this filter to whatever your WebDAV servlet is mapped to.
  */
 
-public class WebdavFixValve
-extends ValveBase {
+public class WebdavFixFilter implements Filter {
+
+@Override
+public void init(FilterConfig filterConfig) throws ServletException {
+}
+
+   @Override
+   public void destroy() {
+   }
 
 /**
  * Check for the broken MS WebDAV client and if detected issue a re-direct
  * that hopefully will cause the non-broken client to be used.
  */
-public void invoke(Request request, Response response)
-throws IOException, ServletException {
-
-String ua = request.getHeader("User-Agent");
-if (ua != null && ua.contains("MiniRedir")) {
-response.sendRedirect(buildRedirect(request));
-} else {
-getNext().invoke(request, response);
+   @Override
+   public void doFilter(ServletRequest request, ServletResponse response,
+   FilterChain chain) throws IOException, ServletException 
{
+   if (!(request instanceof HttpServletRequest) ||
+   !(response instanceof HttpServletResponse)) {
+chain.doFilter(request, response);
+return;
 }
-}
+   HttpServletRequest httpRequest = ((HttpServletRequest) request);
+   HttpServletResponse httpResponse = ((HttpServletResponse) 
response);
+   String ua = httpRequest.getHeader("User-Agent");
+   if (ua != null && ua.contains("MiniRedir")) {
+   httpResponse.sendRedirect(buildRedirect(httpRequest));
+   } else {
+   chain.doFilter(request, response);
+   }   
+   }
 
-private String buildRedirect(Request request) {
+private String buildRedirect(HttpServletRequest request) {
 StringBuffer location =
   
@@ -15,58 +15,76 @@
 
 /**
- * Valve that attempts to force MS WebDAV clients connecting on port 80 to use
+ * Filter that attempts to force MS WebDAV clients connecting on port 80 to use
  * a WebDAV client that actually works. Other workarounds that might help
  * include:

svn commit: r791619 - /tomcat/trunk/webapps/docs/config/filter.xml

2009-07-06 Thread markt
Author: markt
Date: Mon Jul  6 21:19:39 2009
New Revision: 791619

URL: http://svn.apache.org/viewvc?rev=791619&view=rev
Log:
Fix copy and paste error

Modified:
tomcat/trunk/webapps/docs/config/filter.xml

Modified: tomcat/trunk/webapps/docs/config/filter.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/webapps/docs/config/filter.xml?rev=791619&r1=791618&r2=791619&view=diff
==
--
^(TM)

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org